@@ -1036,7 +1036,11 @@ int economy_sysLoad( xmlNodePtr parent )
                   if (xml_isNode(nodeAsset, "planet")) {
                      xmlr_attr(nodeAsset,"name",str);
                      planet = planet_get(str);
+                     if (planet==NULL)
+                        WARN(_("Planet '%s' has saved economy data but doesn't exist!"), str);
                      free(str);
+                     if (planet==NULL)
+                        continue;
                      nodeCommodity = nodeAsset->xmlChildrenNode;
                      do{
                         if (xml_isNode(nodeCommodity, "commodity")) {
