@@ -294,7 +294,7 @@ void equipment_open( unsigned int wid )
       "\anThrust:\n\a0"
       "\anSpeed:\n\a0"
       "\anTurn:\n\a0"
-      "\anTime Dilation:\n\a0"
+      "\anTime Constant:\n\a0"
       "\n"
       "\anAbsorption:\n\a0"
       "\anShield:\n\a0"
@@ -1152,7 +1152,7 @@ void equipment_regenLists( unsigned int wid, int outfits, int ships )
       return;
 
    /* Save focus. */
-   focused = strdup(window_getFocus(wid));
+   focused = window_getFocus( wid );
 
    /* Save positions. */
    if (outfits) {
@@ -1195,7 +1195,8 @@ void equipment_regenLists( unsigned int wid, int outfits, int ships )
 
    /* Restore focus. */
    window_setFocus( wid, focused );
-   free(focused);
+   if (focused != NULL)
+      free( focused );
 }
 
 
