@@ -26,6 +26,7 @@
 #include <ft2build.h>
 #include FT_FREETYPE_H
 #include FT_GLYPH_H
+#include FT_MODULE_H
 
 #include "log.h"
 #include "array.h"
@@ -39,7 +40,9 @@
 #define DEFAULT_TEXTURE_SIZE 1024 /**< Default size of texture caches for glyphs. */
 
 
-static gl_Matrix4 font_projection_mat;
+static gl_Matrix4 font_projection_mat; /**< Projection matrix. */
+static FT_Library font_library = NULL; /**< Global, reference-counted FreeType library. */
+static int        font_library_refs = 0; /**< Our refcount for font_library, because FreeType inexplicably hides its own. */
 
 
 /**
@@ -68,8 +71,7 @@ typedef struct glFontGlyph_s {
    uint32_t codepoint; /**< Real character. */
    GLfloat adv_x; /**< X advancement. */
    GLfloat adv_y; /**< Y advancement. */
-   /* Offsets are stored in the VBO and thus not an issue. */
-   glFontTex *tex; /**< Might be on different texture. */
+   int tex_index; /**< Might be on different texture. */
    GLushort vbo_id; /**< VBO index to use. */
    int next; /**< Stored as a linked list. */
 } glFontGlyph;
@@ -99,7 +101,6 @@ typedef struct font_char_s {
 typedef struct glFontStashFreetype_s {
    char *fontname; /**< Font name. */
    FT_Face face; /**< Face structure. */
-   FT_Library library; /**< Library. */
    FT_Byte *fontdata; /**< Font data buffer. */
 } glFontStashFreetype;
 
@@ -204,7 +205,7 @@ static glFontStash *gl_fontGetStash( const glFont *font )
 static int gl_fontAddGlyphTex( glFontStash *stsh, font_char_t *ch, glFontGlyph *glyph )
 {
    int i, j, n;
-   glFontRow *r, *gr;
+   glFontRow *r, *gr, *lr;
    glFontTex *tex;
    GLfloat *vbo_tex;
    GLshort *vbo_vert;
@@ -213,35 +214,52 @@ static int gl_fontAddGlyphTex( glFontStash *stsh, font_char_t *ch, glFontGlyph *
    GLshort vx, vy, vw, vh;
 
    /* Find free row. */
+   tex = NULL;
    gr = NULL;
    for (i=0; i<array_size( stsh->tex ); i++) {
       for (j=0; j<MAX_ROWS; j++) {
          r = &stsh->tex->rows[j];
-         /* Fits in current row, so use that. */
-         if ((r->h == ch->h) && (r->x+ch->w < stsh->tw)) {
-            tex = &stsh->tex[i];
-            gr = r;
-            break;
+         /* Not empty row and doesn't fit. */
+         if ((r->h != 0) && (r->h != ch->h))
+            continue;
+         if (r->h == ch->h) {
+            /* Fits in current row, so use that. */
+            if (r->x + ch->w <= stsh->tw) {
+               tex = &stsh->tex[i];
+               gr = r;
+               break;
+            }
+            else
+               continue; /* Didn't fit so continue looking. */
          }
-         /* If not empty row, skip. */
          if (r->h != 0)
             continue;
-         /* See if height fits. */
-         if ((j==0) || (stsh->tex->rows[j-1].y+stsh->tex->rows[j-1].h+ch->h < stsh->th)) {
+         /* First row. */
+         if (j==0) {
+            assert( ch->h <= stsh->th ); /* Would be ridiculously large character... */
             r->h = ch->h;
-            if (j>0)
-               r->y = stsh->tex->rows[j-1].y + stsh->tex->rows[j-1].h;
             tex = &stsh->tex[i];
             gr = r;
             break;
          }
+         /* See if height fits to create a new row. */
+         lr = &stsh->tex->rows[j-1];
+         if (lr->y + lr->h + ch->h <= stsh->th) {
+            r->h = ch->h;
+            r->y = lr->y + lr->h;
+            tex = &stsh->tex[i];
+            gr = r;
+         }
+         break; /* Have to break here because either we added a new row or texture is full. */
       }
+      if (gr != NULL)
+         break;
    }
 
    /* Allocate new texture. */
    if (gr == NULL) {
       tex = &array_grow( &stsh->tex );
-      memset( stsh->tex, 0, sizeof(glFontTex) );
+      memset( tex, 0, sizeof(glFontTex) );
 
       glGenTextures( 1, &tex->id );
       glBindTexture( GL_TEXTURE_2D, tex->id );
@@ -345,7 +363,7 @@ static int gl_fontAddGlyphTex( glFontStash *stsh, font_char_t *ch, glFontGlyph *
 
    /* Save glyph data. */
    glyph->vbo_id = (n-8)/2;
-   glyph->tex = tex;
+   glyph->tex_index = tex - stsh->tex;
 
    /* Since the VBOs have possibly changed, we have to reset the data. */
    gl_vboActivateAttribOffset( stsh->vbo_vert, shaders.font.vertex,
@@ -1357,7 +1375,6 @@ static glFontGlyph* gl_fontGetGlyph( glFontStash *stsh, uint32_t ch )
    /* Create new character. */
    glyph = &array_grow( &stsh->glyphs );
    glyph->codepoint = ch;
-   glyph->tex   = NULL;
    glyph->adv_x = ft_char.adv_x;
    glyph->adv_y = ft_char.adv_y;
    glyph->next  = -1;
@@ -1426,7 +1443,7 @@ static int gl_fontRenderGlyph( glFontStash* stsh, uint32_t ch, const glColour *c
    }
 
    /* Activate texture. */
-   glBindTexture(GL_TEXTURE_2D, glyph->tex->id);
+   glBindTexture(GL_TEXTURE_2D, stsh->tex[glyph->tex_index].id);
 
    gl_Matrix4_Uniform(shaders.font.projection, font_projection_mat);
 
@@ -1465,7 +1482,6 @@ static void gl_fontRenderEnd (void)
  */
 int gl_fontInit( glFont* font, const char *fname, const unsigned int h )
 {
-   FT_Library library;
    FT_Face face;
    size_t bufsize;
    FT_Byte* buf;
@@ -1510,13 +1526,15 @@ int gl_fontInit( glFont* font, const char *fname, const unsigned int h )
          }
 
          /* Create a FreeType font library. */
-         if (FT_Init_FreeType(&library)) {
-            WARN(_("FT_Init_FreeType failed with font %s."), ft->fontname);
-            return -1;
+         if (font_library_refs++ == 0) {
+            if (FT_Init_FreeType( &font_library )) {
+               WARN(_("FT_Init_FreeType failed with font %s."), ft->fontname);
+               return -1;
+            }
          }
 
          /* Object which freetype uses to store font info. */
-         if (FT_New_Memory_Face( library, buf, bufsize, 0, &face )) {
+         if (FT_New_Memory_Face( font_library, buf, bufsize, 0, &face )) {
             WARN(_("FT_New_Face failed loading library from %s"), ft->fontname);
             return -1;
          }
@@ -1539,7 +1557,6 @@ int gl_fontInit( glFont* font, const char *fname, const unsigned int h )
 
          /* Save stuff. */
          ft->face     = face;
-         ft->library  = library;
          ft->fontdata = buf;
          ch = i;
          if (fname[i]==',')
@@ -1564,7 +1581,6 @@ int gl_fontInit( glFont* font, const char *fname, const unsigned int h )
    for (i=0; i<128; i++)
       if (isprint(i)) /* Only care about printables. */
          gl_fontGetGlyph( stsh, i );
-
    return 0;
 }
 
@@ -1586,11 +1602,15 @@ void gl_freeFont( glFont* font )
       ft = &stsh->ft[i];
       free(ft->fontname);
       FT_Done_Face(ft->face);
-      //FT_Done_FreeType(ft->library);
       free(ft->fontdata);
    }
    array_free( stsh->ft );
 
+   if (--font_library_refs == 0) {
+      FT_Done_FreeType( font_library );
+      font_library = NULL;
+   }
+
    for (i=0; i<array_size(stsh->tex); i++)
       glDeleteTextures( 1, &stsh->tex->id );
    array_free( stsh->tex );
