@@ -188,8 +188,8 @@ int load_refresh (void)
       len = strlen(files[i]);
 
       /* no save or backup save extension */
-      if (((len < 5) || strcmp(&files[i][len-3],".ns")) &&
-            ((len < 12) || strcmp(&files[i][len-10],".ns.backup"))) {
+      if (((len < 4) || strcmp(&files[i][len-3],".ns")) &&
+            ((len < 11) || strcmp(&files[i][len-10],".ns.backup"))) {
          free(files[i]);
          memmove( &files[i], &files[i+1], sizeof(char*) * (nfiles-i-1) );
          nfiles--;
@@ -200,13 +200,17 @@ int load_refresh (void)
    /* Make sure files are none. */
    if (files == NULL)
       return 0;
+   if (nfiles == 0) {
+      free( files );
+      return 0;
+   }
 
    /* Make sure backups are after saves. */
    for (i=0; i<nfiles-1; i++) {
       len = strlen( files[i] );
 
       /* Only interested in swapping backup with file after it if it's not backup. */
-      if ((len < 12) || strcmp( &files[i][len-10],".ns.backup" ))
+      if ((len < 11) || strcmp( &files[i][len-10],".ns.backup" ))
          continue;
 
       /* Don't match. */
@@ -434,7 +438,7 @@ static void load_menu_load( unsigned int wdw, char *str )
             "   Save version: \ar%s\a0\n"
             "   Naev version: %s\n"
             "Are you sure you want to load this game? It may lose data."),
-            save, ns->version, VERSION ))
+            save, ns[pos].version, VERSION ))
          return;
    }
 
