@@ -141,11 +141,14 @@ int nlua_loadHook( nlua_env env )
  */
 static int hookL_rm( lua_State *L )
 {
-   unsigned int h;
+   long h;
 
    /* Remove the hook. */
-   h = luaL_checklong( L, 1 );
-   hook_rm( h );
+   h = luaL_optlong( L, 1, -1 );
+   /* ... Or do a no-op if caller passes nil. */
+   if (h < 0)
+      return 0;
+   hook_rm( (unsigned int) h );
 
    /* Clean up hook data. */
    nlua_getenv(__NLUA_CURENV, "__hook_arg");
