@@ -817,6 +817,17 @@ void widget_cleanup( Widget *widget )
 }
 
 
+/**
+ * @brief Closes all open toolkit windows.
+ */
+void toolkit_closeAll( void )
+{
+   Window *w;
+   for (w = windows; w != NULL; w = w->next)
+      window_destroy( w->id );
+}
+
+
 /**
  * @brief Helper function to automatically close the window calling it.
  *
@@ -1007,9 +1018,9 @@ void toolkit_drawOutlineThick( int x, int y, int w, int h, int b,
    GLshort tri[5][4];
    glColour colours[10];
 
-   x -= b - thick;
+   x -= (b - thick);
    w += 2 * (b - thick);
-   y -= b - thick;
+   y -= (b - thick);
    h += 2 * (b - thick);
    lc = lc ? lc : c;
 
@@ -2222,7 +2233,8 @@ static Widget* toolkit_getFocus( Window *wdw )
  * @brief Sets the focused widget in a window.
  *
  *    @param wid ID of the window to get widget from.
- *    @param wgtname Name of the widget to set focus to.
+ *    @param wgtname Name of the widget to set focus to,
+ *                   or NULL to clear the focus.
  */
 void window_setFocus( const unsigned int wid, const char* wgtname )
 {
@@ -2234,12 +2246,13 @@ void window_setFocus( const unsigned int wid, const char* wgtname )
    if (wdw == NULL)
       return;
 
+   toolkit_focusClear( wdw );
+
    /* Get widget. */
-   wgt = window_getwgt(wid,wgtname);
+   wgt = wgtname==NULL ? NULL : window_getwgt( wid, wgtname );
    if (wgt == NULL)
       return;
 
-   toolkit_focusClear( wdw );
    toolkit_focusWidget( wdw, wgt );
 }
 
@@ -2248,7 +2261,7 @@ void window_setFocus( const unsigned int wid, const char* wgtname )
  * @brief Gets the focused widget in a window.
  *
  *    @param wid ID of the window to get widget from.
- *    @return The focused widget's name.
+ *    @return The focused widget's name (strdup()ed string or NULL).
  */
 char* window_getFocus( const unsigned int wid )
 {
@@ -2263,7 +2276,7 @@ char* window_getFocus( const unsigned int wid )
    /* Find focused widget. */
    for (wgt=wdw->widgets; wgt!=NULL; wgt=wgt->next)
       if (wgt->id == wdw->focus)
-         return wgt->name;
+         return strdup( wgt->name );
 
    return NULL;
 }
